pub enum ErrorCode {
Show 14 variants
NoError = 0,
ProtocolError = 1,
InternalError = 2,
FlowControlError = 3,
SettingsTimeout = 4,
StreamClosed = 5,
FrameSizeError = 6,
RefusedStream = 7,
Cancel = 8,
CompressionError = 9,
ConnectError = 10,
EnhanceYourCalm = 11,
InadequateSecurity = 12,
Http11Required = 13,
}Expand description
The enum represents an error code that are used in RST_STREAM and GOAWAY frames.
These are defined in Section 7 of the HTTP/2
spec.
Variants
NoError = 0
The associated condition is not a result of an error. For example, a GOAWAY might include this code to indicate graceful shutdown of a connection.
ProtocolError = 1
The endpoint detected an unspecific protocol error. This error is for use when a more specific error code is not available.
InternalError = 2
The endpoint encountered an unexpected internal error.
FlowControlError = 3
The endpoint detected that its peer violated the flow-control protocol.
SettingsTimeout = 4
The endpoint sent a SETTINGS frame but did not receive a response in a timely manner. See Section 6.5.3 (“Settings Synchronization”).
StreamClosed = 5
The endpoint received a frame after a stream was half-closed.
FrameSizeError = 6
The endpoint received a frame with an invalid size.
RefusedStream = 7
The endpoint refused the stream prior to performing any application processing (see Section 8.1.4 for details).
Cancel = 8
Used by the endpoint to indicate that the stream is no longer needed.
CompressionError = 9
The endpoint is unable to maintain the header compression context for the connection.
ConnectError = 10
The connection established in response to a CONNECT request (Section 8.3) was reset or abnormally closed.
EnhanceYourCalm = 11
The endpoint detected that its peer is exhibiting a behavior that might be generating excessive load.
InadequateSecurity = 12
The underlying transport has properties that do not meet minimum security requirements (see Section 9.2).
Http11Required = 13
The endpoint requires that HTTP/1.1 be used instead of HTTP/2.