Module httpbis::error
[−]
[src]
Enums
| Error |
An enum representing errors that can arise when performing operations involving an HTTP/2 connection. |
| ErrorCode |
The enum represents an error code that are used in |