pub struct ServerRequest<'a> {
pub headers: Headers,
pub end_stream: bool,
/* private fields */
}Fields
headers: HeadersRequest headers
end_stream: boolTrue if requests ends with headers
Implementations
Sourceimpl<'a> ServerRequest<'a>
impl<'a> ServerRequest<'a>
pub fn make_stream(self) -> HttpStreamAfterHeaders
Sourcepub fn register_stream_handler<F, H, R>(self, f: F) -> R
pub fn register_stream_handler<F, H, R>(self, f: F) -> R
Register synchnous stream handler (callback will be called immediately when new data arrives). Note that increasing in window size is the handler responsibility.